@@ -34,6 +34,7 @@ import shutil
 import hashlib
 import posixpath
 import ctypes
+import subprocess
 
 
 dotfiles_root = os.path.join(*[os.path.expanduser("~"), "dotfiles"])
@@ -57,7 +58,10 @@ def __save_config(config):
 
 
 def __get_os_name():
-    return platform.system().lower()
+    os_name = platform.system().lower()
+    if os_name == "linux" and subprocess.check_output(['uname', '-o']).strip() == b'Android':
+        return "android"
+    return os_name
 
 
 def __normalize_path(path):
